@@ -64,6 +64,8 @@ static bool fileIsStillChanging(const SyncFileItem &item)
 PUTFileJob::PUTFileJob(AccountPtr account, const QString &path, std::unique_ptr<QIODevice> device, const QMap<QByteArray, QByteArray> &headers, int chunk, QObject *parent)
     : PUTFileJob(account, Utility::concatUrlPath(account->davUrl(), path), std::move(device), headers, chunk, parent)
 {
+    // Long uploads must not block non-propagation jobs.
+    setPriority(QNetworkRequest::LowPriority);
 }
 
 PUTFileJob::PUTFileJob(AccountPtr account, const QUrl &url, std::unique_ptr<QIODevice> device, const QMap<QByteArray, QByteArray> &headers, int chunk, QObject *parent)
@@ -74,6 +76,8 @@ PUTFileJob::PUTFileJob(AccountPtr account, const QUrl &url, std::unique_ptr<QIOD
     , _chunk(chunk)
 {
     _device->setParent(this);
+    // Long uploads must not block non-propagation jobs.
+    setPriority(QNetworkRequest::LowPriority);
 }
 
 PUTFileJob::~PUTFileJob()
@@ -88,9 +92,6 @@ void PUTFileJob::start()
     for (auto it = _headers.cbegin(); it != _headers.cend(); ++it) {
         req.setRawHeader(it.key(), it.value());
     }
-
-    req.setPriority(QNetworkRequest::LowPriority); // Long uploads must not block non-propagation jobs.
-
     sendRequest("PUT", _url, req, _device);
 
     connect(this, &AbstractNetworkJob::networkActivity, account().data(), &Account::propagatorNetworkActivity);
